==> adios2-2.10.2-11-x86_64.pkg.tar.zst: usr/lib/cmake/adios2/adios2-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "adios2::perfstubs" for configuration "None"
set_property(TARGET adios2::perfstubs APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::perfstubs PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_perfstubs.so.2.10.2"
  IMPORTED_SONAME_NONE "libadios2_perfstubs.so.2.10"
  )

list(APPEND _cmake_import_check_targets adios2::perfstubs )
list(APPEND _cmake_import_check_files_for_adios2::perfstubs "${_IMPORT_PREFIX}/lib/libadios2_perfstubs.so.2.10.2" )

# Import target "adios2::core" for configuration "None"
set_property(TARGET adios2::core APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "adios2::core_cuda;Blosc2::blosc2_shared;zfp::zfp;mgard::mgard"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core.so.2.10.2"
  IMPORTED_SONAME_NONE "libadios2_core.so.2.10"
  )

list(APPEND _cmake_import_check_targets adios2::core )
list(APPEND _cmake_import_check_files_for_adios2::core "${_IMPORT_PREFIX}/lib/libadios2_core.so.2.10.2" )

# Import target "adios2::core_mpi" for configuration "None"
set_property(TARGET adios2::core_mpi APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core_mpi PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core_mpi.so.2.10.2"
  IMPORTED_SONAME_NONE "libadios2_core_mpi.so.2.10"
  )

list(APPEND _cmake_import_check_targets adios2::core_mpi )
list(APPEND _cmake_import_check_files_for_adios2::core_mpi "${_IMPORT_PREFIX}/lib/libadios2_core_mpi.so.2.10.2" )

# Import target "adios2::core_cuda" for configuration "None"
set_property(TARGET adios2::core_cuda APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core_cuda PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core_cuda.so"
  IMPORTED_SONAME_NONE "libadios2_core_cuda.so"
  )

list(APPEND _cmake_import_check_targets adios2::core_cuda )
list(APPEND _cmake_import_check_files_for_adios2::core_cuda "${_IMPORT_PREFIX}/lib/libadios2_core_cuda.so" )

# Import target "adios2::EncryptionOperator" for configuration "None"
set_property(TARGET adios2::EncryptionOperator APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::EncryptionOperator PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libEncryptionOperator.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets adios2::EncryptionOperator )
list(APPEND _cmake_import_check_files_for_adios2::EncryptionOperator "${_IMPORT_PREFIX}/lib/libEncryptionOperator.so" )

# Import target "adios2::ParaViewADIOSInSituEngine" for configuration "None"
set_property(TARGET adios2::ParaViewADIOSInSituEngine APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::ParaViewADIOSInSituEngine PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libParaViewADIOSInSituEngine.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets adios2::ParaViewADIOSInSituEngine )
list(APPEND _cmake_import_check_files_for_adios2::ParaViewADIOSInSituEngine "${_IMPORT_PREFIX}/lib/libParaViewADIOSInSituEngine.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> adios2-2.11.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/adios2/adios2-targets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "adios2::perfstubs" for configuration "None"
set_property(TARGET adios2::perfstubs APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::perfstubs PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_perfstubs.so.2.11.0"
  IMPORTED_SONAME_NONE "libadios2_perfstubs.so.2.11"
  )

list(APPEND _cmake_import_check_targets adios2::perfstubs )
list(APPEND _cmake_import_check_files_for_adios2::perfstubs "${_IMPORT_PREFIX}/lib/libadios2_perfstubs.so.2.11.0" )

# Import target "adios2::core" for configuration "None"
set_property(TARGET adios2::core APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "adios2::core_cuda;sodium;Blosc2::blosc2_shared;zfp::zfp;mgard::mgard"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core.so.2.11.0"
  IMPORTED_SONAME_NONE "libadios2_core.so.2.11"
  )

list(APPEND _cmake_import_check_targets adios2::core )
list(APPEND _cmake_import_check_files_for_adios2::core "${_IMPORT_PREFIX}/lib/libadios2_core.so.2.11.0" )

# Import target "adios2::core_mpi" for configuration "None"
set_property(TARGET adios2::core_mpi APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core_mpi PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core_mpi.so.2.11.0"
  IMPORTED_SONAME_NONE "libadios2_core_mpi.so.2.11"
  )

list(APPEND _cmake_import_check_targets adios2::core_mpi )
list(APPEND _cmake_import_check_files_for_adios2::core_mpi "${_IMPORT_PREFIX}/lib/libadios2_core_mpi.so.2.11.0" )

# Import target "adios2::core_cuda" for configuration "None"
set_property(TARGET adios2::core_cuda APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::core_cuda PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libadios2_core_cuda.so"
  IMPORTED_SONAME_NONE "libadios2_core_cuda.so"
  )

list(APPEND _cmake_import_check_targets adios2::core_cuda )
list(APPEND _cmake_import_check_files_for_adios2::core_cuda "${_IMPORT_PREFIX}/lib/libadios2_core_cuda.so" )

# Import target "adios2::EncryptionOperator" for configuration "None"
set_property(TARGET adios2::EncryptionOperator APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::EncryptionOperator PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libEncryptionOperator.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets adios2::EncryptionOperator )
list(APPEND _cmake_import_check_files_for_adios2::EncryptionOperator "${_IMPORT_PREFIX}/lib/libEncryptionOperator.so" )

# Import target "adios2::ParaViewADIOSInSituEngine" for configuration "None"
set_property(TARGET adios2::ParaViewADIOSInSituEngine APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(adios2::ParaViewADIOSInSituEngine PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NONE ""
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libParaViewADIOSInSituEngine.so"
  IMPORTED_NO_SONAME_NONE "TRUE"
  )

list(APPEND _cmake_import_check_targets adios2::ParaViewADIOSInSituEngine )
list(APPEND _cmake_import_check_files_for_adios2::ParaViewADIOSInSituEngine "${_IMPORT_PREFIX}/lib/libParaViewADIOSInSituEngine.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
